@@ -31,6 +31,6 @@ the `openpyxl` package.
 
 from rumydata import field
 from rumydata import rules
-from rumydata.file import Layout, File
+from rumydata.table import Layout, File
 
-__version__ = '0.0.13'
+__version__ = '0.1.0'
