@@ -21,12 +21,12 @@ potential to introduce performance impacts.
 from typing import List
 
 from rumydata import exception as ex
-from rumydata.base import BaseRule
+from rumydata._base import _BaseRule
 
 __all__ = ['Unique']
 
 
-class Rule(BaseRule):
+class Rule(_BaseRule):
     """ Column Rule """
 
     def _prepare(self, data: List[str]) -> tuple:
@@ -36,7 +36,7 @@ class Rule(BaseRule):
 class Unique(Rule):
     """ Column values unique Rule """
 
-    exception_class = ex.DuplicateValueError
+    _exception_class = ex.DuplicateValueError
 
     def _prepare(self, data: List[str]) -> tuple:
         return [x for x in data if not x == ''],
@@ -45,7 +45,7 @@ class Unique(Rule):
         return lambda x: len(x) == len(set(x))
 
     def _exception_msg(self):
-        return self.exception_class(self._explain())
+        return self._exception_class(self._explain())
 
     def _explain(self):
         return 'values must be unique'
