@@ -9,13 +9,13 @@ the expected number of values, before attempting to validate individual cells.
 from typing import List
 
 from rumydata import exception as ex
-from rumydata.base import BaseRule
+from rumydata._base import _BaseRule
 
 
-class Rule(BaseRule):
+class Rule(_BaseRule):
     """ Row Rule """
 
-    exception_class = ex.RowComparisonError
+    _exception_class = ex.RowComparisonError
 
     def _prepare(self, data: List[str]) -> tuple:
         return data,
@@ -24,9 +24,11 @@ class Rule(BaseRule):
 class RowLengthLTE(Rule):
     """ Row length less than or equal to Rule """
 
-    exception_class = ex.RowLengthError
+    _exception_class = ex.RowLengthError
+    _default_args = (1,)
 
     def __init__(self, columns_length):
+        super().__init__()
         self.columns_length = columns_length
 
     def _evaluator(self):
@@ -39,9 +41,11 @@ class RowLengthLTE(Rule):
 class RowLengthGTE(Rule):
     """ Row greater than or equal to Rule """
 
-    exception_class = ex.RowLengthError
+    _exception_class = ex.RowLengthError
+    _default_args = (1,)
 
     def __init__(self, columns_length):
+        super().__init__()
         self.columns_length = columns_length
 
     def _evaluator(self):
